SyncAlias

Trait SyncAlias 

pub trait SyncAlias { }
Trait alias for Sync

If the rayon feature is set, it acts as an alias for Sync and is implemented for all types which implement Sync. If rayon is not set, it will be an “empty” trait implemented for all types.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> SyncAlias for T

Available on non-crate feature rayon only.