pub struct CauchyPoint<F> { /* private fields */ }Expand description
Cauchy point method
The Cauchy point is the minimum of the quadratic approximation of the cost function within the trust region along the direction given by the first derivative.
Requirements on the optimization problem
The optimization problem is required to implement Gradient and Hessian.
Reference
Jorge Nocedal and Stephen J. Wright (2006). Numerical Optimization. Springer. ISBN 0-387-30303-0.
Implementations
Sourceimpl<F> CauchyPoint<F>where
F: ArgminFloat,
impl<F> CauchyPoint<F>where
F: ArgminFloat,