Crate argmin [−] [src]
Optimizaton toolbox
TODOs
- Stopping criterions which can be stacked, also return the reason why a computation terminated
- keep track of cost function values
- count the number of cost function / gradient evaluations and return them
Reexports
pub use problem::ArgminProblem; |
pub use operator::ArgminOperator; |
pub use result::ArgminResult; |
pub use sa::SimulatedAnnealing; |
pub use sa::SATempFunc; |
pub use newton::Newton; |
pub use cg::ConjugateGradient; |
pub use gradientdescent::GradientDescent; |
pub use gradientdescent::GDGammaUpdate; |
pub use backtracking::BacktrackingLineSearch; |
pub use landweber::Landweber; |
pub use neldermead::NelderMead; |
pub use termination::TerminationReason; |
Modules
| backtracking |
Backtracking line search Backtracking Line Search |
| cg |
Conjugate Gradient method Conjugate Gradient method |
| gradientdescent |
Gradient Descent Gradient Descent |
| landweber |
Landweber algorithm Landweber algorithm |
| macros |
Macros TODO Documentation |
| neldermead |
Nelder Mead method Nelder-Mead method |
| newton |
Newton method Newton method |
| operator |
Operator TODO DOCUMENTATION |
| parameter |
Traits for implementing parameter vectors TODO DOCUMENTATION |
| prelude |
Definition of all relevant traits Gets common traits into scope |
| problem |
Problem formulation TODO DOCUMENTATION |
| result |
Definition of the return type of the solvers
|
| sa |
Simulated Annealing TODO |
| termination |
Termination reasons TODO Documentation |
| testfunctions |
A set of test functions like Rosenbrock's function and so on. TODO Documentation |
Macros
| make_run |
This macro generates the |
| make_terminate |
This macro generates the |
Traits
| ArgminCostValue |
Trait for cost function values TODO: Do this with trait aliases once they work in rust. |
| ArgminSolver |
Trait every solve needs to implement (in the future) |