argmin optimization toolbox core
This module contains the traits and types necessary for implementing optimization algorithms and tools for observing the state of optimization runs and checkpointing.
Re-exports
pub use crate::solver::conjugategradient::beta::NLCGBetaUpdate;pub use crate::solver::linesearch::LineSearch;pub use crate::solver::trustregion::TrustRegionRadius;
Modules
- checkpointing
- Checkpointing
- macros
- Macros
- observers
- Observers
- test_
utils - Convenience utilities for testing
Structs
- Error
- The
Errortype, a wrapper around a dynamic error type. - Executor
- Solves an optimization problem with a solver
- Iter
State - Maintains the state from iteration to iteration of a solver
- KV
- A simple key-value storage
- Linear
Program State - Maintains the state from iteration to iteration of a solver
- Optimization
Result - Result of an optimization returned by after running an
Executor. - Population
State - Maintains the state from iteration to iteration of a population-based solver
- Problem
- Wrapper around problems defined by users.
Enums
- Argmin
Error - Argmin error type
- KvValue
- Types available for use in
KV. - Termination
Reason - Reasons for optimization algorithms to stop
- Termination
Status - Status of optimization execution
Traits
- Argmin
Float - An alias for float types (
f32,f64) which combines multiple commonly needed traits fromnum_traits,std::fmtand for serialization/deserialization (the latter only if theserde1feature is enabled). It is automatically implemented for all types which fulfill the trait bounds. - Cost
Function - Defines computation of a cost function value
- Gradient
- Defines the computation of the gradient.
- Hessian
- Defines the computation of the Hessian.
- Jacobian
- Defines the computation of the Jacobian.
- Linear
Program - Defines a linear Program
- Operator
- Defines the application of an operator to a parameter vector.
- Send
Alias - Trait alias for
Send - Solver
- The interface all solvers are required to implement.
- State
- Minimal interface which struct used for managing state in solvers have to implement.
- Sync
Alias - Trait alias for
Sync