pub trait SendAlias { }Expand description
Trait alias for Send
If the rayon feature is set, it acts as an alias for Send and is implemented for all
types which implement Send. If rayon is not set, it will be an “empty” trait
implemented for all types.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".